@@ -7,6 +7,7 @@ from docanalysis.xml_lib import XmlLib
 
 
 class AMIAbsSection(ABC):
+    """ """
     logger = logging.getLogger("ami_abs_section")
 
     SECTIONS = "sections"
@@ -17,7 +18,13 @@ class AMIAbsSection(ABC):
     
     @classmethod
     def make_xml_sections(cls, file, outdir: str, force: bool) -> None:
-        """make sections """
+        """make sections
+
+        :param file: 
+        :param outdir: str: 
+        :param force: bool: 
+
+        """
         if file is None or outdir is None:
             return None
         path = Path(file)
@@ -35,10 +42,10 @@ class AMIAbsSection(ABC):
 
 class AMIFigure(AMIAbsSection):
     """holds data on figure captions and hopefully later pointers to pdfimages
-
+    
     Figures are a mess in JATS. They can be held in different places and often not linked
     to the bitmap. This class will include heuristics for uniting and standardising this.
-
+    
     JATS encoding depends on the publisher. Typically:
     <fig xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:mml="http://www.w3.org/1998/Math/MathML" id="F6"
          fig-type="figure" orientation="portrait" position="float">
@@ -50,8 +57,10 @@ class AMIFigure(AMIAbsSection):
       </caption>
       <graphic xlink:href="aay7633-F6"/>
     </fig>'
-
+    
     There are sometimes 2 or more <p> as children of caption.
+
+
     """
 
     # JATS tags
@@ -74,6 +83,11 @@ class AMIFigure(AMIAbsSection):
 
     @classmethod
     def create_from_jats(cls, xml_path):
+        """
+
+        :param xml_path: 
+
+        """
         ami_figure = AMIFigure()
         ami_figure.root = XmlLib.parse_xml_file_to_root(str(xml_path))
         ami_figure.add_figure_structure()
@@ -91,6 +105,7 @@ class AMIFigure(AMIAbsSection):
         self.title_text = XmlLib.get_text(self.caption_title)
 
     def get_xml_str(self):
+        """ """
         return LXET.tostring(self.root)
 
     def __str__(self):
